containertools.get_first_element_starting_at_or_after_prolated_offset
=====================================================================

.. autofunction:: abjad.tools.containertools.get_first_element_starting_at_or_after_prolated_offset.get_first_element_starting_at_or_after_prolated_offset
